==> prestashop_1.4.8.2.zip: prestashop/modules/canadapost/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{canadapost}prestashop>canadapost_77946efda9f40f6bbcd0e697de948e65'] = 'Canada Post Carrier';
$_MODULE['<{canadapost}prestashop>canadapost_a5daea18a1d4214028a538c3bf5a41cc'] = 'Offrire ai vostri clienti, modalità di consegna diversi post con il Canada';
$_MODULE['<{canadapost}prestashop>canadapost_9d7d8be1feb0bc026fffd29bc536364e'] = 'cURL opzione';
$_MODULE['<{canadapost}prestashop>canadapost_883fa0069f4b0454e2277dd567ab3991'] = '\'Unità di Peso (LB o KG).\'';
$_MODULE['<{canadapost}prestashop>canadapost_5a3ceec65d417f5d92c26dbf0dccc00d'] = '\'Unità Dimensioni (CM o IN).\'';
$_MODULE['<{canadapost}prestashop>canadapost_4d470fde8487e755a50e9235e3dc13ab'] = 'deve essere configurato per utilizzare questo modulo correttamente';
$_MODULE['<{canadapost}prestashop>canadapost_2056ed4f6b76a94035f12c041350aa2f'] = 'Canada Post conto';
$_MODULE['<{canadapost}prestashop>canadapost_20449d3f0b6c6b9265a5cd2a470a6451'] = 'Packaging peso';
$_MODULE['<{canadapost}prestashop>canadapost_bfc00de34bc04366e7fee516adf7dca5'] = 'La tassa';
$_MODULE['<{canadapost}prestashop>canadapost_386aad80d82f8245e9ef80352a2240e8'] = 'Tutti gli articoli in un unico pacchetto';
$_MODULE['<{canadapost}prestashop>canadapost_f35eb2a913a3fd6fd8e661012cf0ebd8'] = 'Dividere un elemento per ogni pacchetto';
$_MODULE['<{canadapost}prestashop>canadapost_9c536dc938b99309eab40c9a06fc1c00'] = 'Canada Post Modulo di stato';
$_MODULE['<{canadapost}prestashop>canadapost_428a446c88625404645d482927d90b31'] = 'Carrier Canada Post è configurato e online!';
$_MODULE['<{canadapost}prestashop>canadapost_c31be897c51c899fe1da81c31403e2a4'] = 'Carrier Canada Post non è ancora configurato, è necessario:';
$_MODULE['<{canadapost}prestashop>canadapost_3e203b9a16f360b88d90bba6eb61ce61'] = 'Riempire il \"Impostazioni generali\" forma';
$_MODULE['<{canadapost}prestashop>canadapost_8c0987b9315003df7dae7f130e3cf58e'] = 'Selezionare il servizio di consegna';
$_MODULE['<{canadapost}prestashop>canadapost_e20f6d6f13fe70e78f6e2ab488493ccf'] = 'Webservice test di connessione';
$_MODULE['<{canadapost}prestashop>canadapost_5378f4ad5f6616fda3ef972deba67f8a'] = 'cURL è abilitato';
$_MODULE['<{canadapost}prestashop>canadapost_52f4393e1b52ba63e27310ca92ba098c'] = 'Impostazioni generali';
$_MODULE['<{canadapost}prestashop>canadapost_277d63a9b24a09697e3c64092eaf4353'] = 'Categorie Impostazioni';
$_MODULE['<{canadapost}prestashop>canadapost_098eec2cabe2c39c6dec3fc522b6571a'] = 'Prodotti Impostazioni';
$_MODULE['<{canadapost}prestashop>canadapost_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aiuto';
$_MODULE['<{canadapost}prestashop>canadapost_d2126da975d5b9a5b846efaf57d3fd53'] = 'Configurazione generale';
$_MODULE['<{canadapost}prestashop>canadapost_4af6ad356ba7dd056b265944ef91cb5b'] = 'Apri il tuo conto in Canada';
$_MODULE['<{canadapost}prestashop>canadapost_db06a2900c66a3a2cb78fe3a470f1b85'] = 'Imballo Peso';
$_MODULE['<{canadapost}prestashop>canadapost_0274f749472f365e7d48a501e14793e6'] = 'Handling Fee';
$_MODULE['<{canadapost}prestashop>canadapost_83ad4fdaf06650e6d9d7ca18f82fb975'] = 'Localizzazione di configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_f489118ea95c746d648d36bb50c226f0'] = 'Unità di peso';
$_MODULE['<{canadapost}prestashop>canadapost_659c95668841b7d6602ead454b28d4ba'] = 'L\'unità di peso del tuo negozio (es. kg o lbs)';
$_MODULE['<{canadapost}prestashop>canadapost_cc13d156306185fd42a860da3049567c'] = 'Dimensioni unità';
$_MODULE['<{canadapost}prestashop>canadapost_f804c2bdebc117d9cde3cddad3b49845'] = 'L\'unità di dimensione del tuo negozio (cm ad esempio o in)';
$_MODULE['<{canadapost}prestashop>canadapost_2481447d04ae756836d32e3ade240ff4'] = 'Indirizzo di configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_5b179e75d464a04d8a04111131b3a3ca'] = 'La tua linea indirizzo 1';
$_MODULE['<{canadapost}prestashop>canadapost_281b2def1a9737b33f88013c94fdfeb8'] = 'La tua linea indirizzo 2';
$_MODULE['<{canadapost}prestashop>canadapost_d30f507473129e70c4b962ceccf175cf'] = '/ Codice postale';
$_MODULE['<{canadapost}prestashop>canadapost_d0585aac6bb77bb49423b2effca0e067'] = 'Il tuo Comune';
$_MODULE['<{canadapost}prestashop>canadapost_59716c97497eb9694541f7c3d37b1a4d'] = 'Paese';
$_MODULE['<{canadapost}prestashop>canadapost_f8f5a972333ee726fbe5bb52409c0ed0'] = 'Scegliere un paese ...';
$_MODULE['<{canadapost}prestashop>canadapost_4e9863cf5326e6714388045321665d07'] = 'Seleziona il paese all\'interno della lista.';
$_MODULE['<{canadapost}prestashop>canadapost_46a2a41cc6e552044816a2d04634545d'] = 'Stato';
$_MODULE['<{canadapost}prestashop>canadapost_cf1580798f7aba85d519afadf1ffd886'] = 'Seleziona uno stato ...';
$_MODULE['<{canadapost}prestashop>canadapost_02546d525ab356bd43c91e6b07447496'] = 'Non c\'è nessuna configurazione di stato per questo paese';
$_MODULE['<{canadapost}prestashop>canadapost_0ddc2a5660f7d095fff34d6b93077c80'] = 'Servizio di configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_8d6bd50f3fe3ee2f4513066c25e5fb4a'] = 'Calcul modalità';
$_MODULE['<{canadapost}prestashop>canadapost_79a7b64f7e16759d93ef3e74f1916815'] = 'Utilizzando la modalità di calcul \"Tutti gli elementi in un unico pacchetto\" utilizzerà automaticamente imballaggio dimensioni predefinite e servizi di consegna. Configurazioni specifiche per le categorie o prodotto non sarà utilizzato.';
$_MODULE['<{canadapost}prestashop>canadapost_5cdd307ba6e260beb4801c0c10e22a3a'] = 'Service Delivery';
$_MODULE['<{canadapost}prestashop>canadapost_78945de8de090e90045d299651a68a9b'] = 'Disponibile';
$_MODULE['<{canadapost}prestashop>canadapost_2d25c72c1b18e562f6654fff8e11711e'] = 'Non disponibile';
$_MODULE['<{canadapost}prestashop>canadapost_d63e135774e62574e2a1921267dad142'] = 'Scegliere il servizio di consegna che sarà disponibile per i clienti.';
$_MODULE['<{canadapost}prestashop>canadapost_a438cfa1a870740754c9f4b35130cc04'] = 'Il tuo account Invia il Canada non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_805353d2862ea0e658c9ddda871540fa'] = 'Il tuo codice Zip / Postal non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_ef9bd955e165dfb0207877e9fe180aeb'] = 'La tua città non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_5ecc7697a320f93f3ee8fb4048dbd64c'] = 'Il vostro paese non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_e7bb7d2ee4d79c9b48cfc443781f00b5'] = 'Prestashop Impossibile connettersi al Canada Post webservices';
$_MODULE['<{canadapost}prestashop>canadapost_9d1b485edd50e6fbd288b340b386b07d'] = 'Nessuna descrizione dell\'errore trovato';
$_MODULE['<{canadapost}prestashop>canadapost_c888438d14855d7d96a2724ee9c306bd'] = 'Impostazioni aggiornate';
$_MODULE['<{canadapost}prestashop>canadapost_b9284bff13acffdd879ef4ac7fca5234'] = 'Impostazioni fallito';
$_MODULE['<{canadapost}prestashop>canadapost_67e19ffdaa0a11e69349810403a9727e'] = 'È necessario configurare \"Impostazioni generali\" sulla scheda prima di utilizzare questa scheda.';
$_MODULE['<{canadapost}prestashop>canadapost_a37b48e8684078c0620a997b3baeee9f'] = 'In questa scheda è possibile impostare una configurazione specifica per ogni categoria.';
$_MODULE['<{canadapost}prestashop>canadapost_f421827ff72ef9a61fb27aa0de62f1e4'] = 'ID Config';
$_MODULE['<{canadapost}prestashop>canadapost_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Categoria';
$_MODULE['<{canadapost}prestashop>canadapost_20cde117cbc92b9ec1fb4e5bc4a7b9bd'] = 'Costi aggiuntivi';
$_MODULE['<{canadapost}prestashop>canadapost_992a0f0542384f1ee5ef51b7cf4ae6c4'] = 'Servizi';
$_MODULE['<{canadapost}prestashop>canadapost_06df33001c1d7187fdd81ea1f5b277aa'] = 'Azioni';
$_MODULE['<{canadapost}prestashop>canadapost_66001bafca8edd8343802bd20cddc10e'] = 'Non c\'è configurazione specifica Canada Post per le categorie a questo punto.';
$_MODULE['<{canadapost}prestashop>canadapost_605c5ae9959cfe9cc0b0d630b8d3144f'] = 'Sei sicuro di voler cancellare questa specifica configurazione Canada Post per questa categoria?';
$_MODULE['<{canadapost}prestashop>canadapost_3e0cb9fd22b124c0839302fef54762d7'] = 'Aggiornamento di una regola';
$_MODULE['<{canadapost}prestashop>canadapost_dd593f8a542ab628cbba98c709255e60'] = 'Aggiungere una regola';
$_MODULE['<{canadapost}prestashop>canadapost_7fcafa7c47e984693fcb8a92c0fd1beb'] = 'Seleziona una categoria ...';
$_MODULE['<{canadapost}prestashop>canadapost_d725c0166e978cc30853996c70440873'] = 'È necessario selezionare una categoria.';
$_MODULE['<{canadapost}prestashop>canadapost_882830cb67e4069370c1be3a1ba4e12a'] = 'Questa categoria ha già una specifica configurazione Canada Post.';
$_MODULE['<{canadapost}prestashop>canadapost_fd0119c2a5fc18aa64887b5b7ab41c19'] = 'È verificato un errore, riprova.';
$_MODULE['<{canadapost}prestashop>canadapost_20f40087c53c662adfb4e780500eaa15'] = 'In questa scheda è possibile impostare una configurazione specifica per ogni prodotto.';
$_MODULE['<{canadapost}prestashop>canadapost_deb10517653c255364175796ace3553f'] = 'Prodotto';
$_MODULE['<{canadapost}prestashop>canadapost_2119cb0eeb7e202767f9fa56566efc50'] = 'Non c\'è configurazione specifica Canada Post per i prodotti a questo punto.';
$_MODULE['<{canadapost}prestashop>canadapost_d53b004866635789a76380f66c87e3df'] = 'Sei sicuro di voler cancellare questa specifica configurazione Canada Post per questo prodotto?';
$_MODULE['<{canadapost}prestashop>canadapost_3c4d710b56f4318dae775cff80619f84'] = 'Selezionare un prodotto ...';
$_MODULE['<{canadapost}prestashop>canadapost_9c07640370e4681bf98638d0c458cd2e'] = 'È necessario selezionare un prodotto.';
$_MODULE['<{canadapost}prestashop>canadapost_c018b9a37818d15477285eb915590d19'] = 'Questo prodotto ha già una specifica configurazione Canada Post.';
$_MODULE['<{canadapost}prestashop>canadapost_73e383f703902e137c2e6d8e2e85cc22'] = 'Benvenuti nel PrestaShop Canada Invia modulo configuratore.';
$_MODULE['<{canadapost}prestashop>canadapost_92640c80a67da1782a18304336405dac'] = 'Questa sezione vi aiuterà a capire come configurare questo modulo in modo corretto.';
$_MODULE['<{canadapost}prestashop>canadapost_ec0e6948e8f34818d80f27c309f46661'] = 'Vedi sotto per la descrizione di ogni campo:';
$_MODULE['<{canadapost}prestashop>canadapost_a5f7df92d8088761b0727fb1ce0a013a'] = 'Il tuo account Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_742e9dca63ccb97a592727c4c2c9abc8'] = 'È necessario iscriversi al sito Canada messaggio a questo indirizzo';
$_MODULE['<{canadapost}prestashop>canadapost_35ba940948fa0ea163fd01281de10e2f'] = 'Questo campo deve essere lo Zip / CAP del punto di pacchetto di partenza.';
$_MODULE['<{canadapost}prestashop>canadapost_81822348ace1ceabad5e9f8992ce9ea4'] = 'Questo campo deve essere il paese del punto di pacchetto di partenza.';
$_MODULE['<{canadapost}prestashop>canadapost_b9bba478eb4348e49e672e944b072b68'] = 'Queste caselle corrispondono ai servizi di consegna si vuole essere a disposizione (quando non c\'è nessuna configurazione specifica per il prodotto o la categoria di prodotto).';
$_MODULE['<{canadapost}prestashop>canadapost_b7c1051bdf970e718e2a3664ad3e31ac'] = 'Questa sezione consente di definire una specifica configurazione Canada Post per categoria di prodotti (quali oneri aggiuntivi).';
$_MODULE['<{canadapost}prestashop>canadapost_2911404cfaf6a4c3a6756e157b0edb62'] = 'Questa sezione consente di definire una specifica configurazione Canada Post per ogni prodotto (quali oneri aggiuntivi).';
$_MODULE['<{canadapost}prestashop>canadapost_902b0d55fddef6f8d651fe1035b7d4bd'] = 'Errore';
$_MODULE['<{canadapost}prestashop>canadapost_43c9c583cfcb8523ad269708ddcde8b8'] = 'Canada Webservice messaggio sembra essere il basso, si prega di attendere alcuni minuti e riprovare.';
$_MODULE['<{canadapost}prestashop>canadapost_f1c83c0ed9e0f992f7f448f7321d9743'] = 'Canada Webservice Messaggio scaduta.';
$_MODULE['<{canadapost}prestashop>canadapost_b7f155fe0169108902b447f572639d0b'] = 'Impossibile connettersi al CanadaPost.com';

==> prestashop_1.4.9.0.zip: prestashop/modules/canadapost/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{canadapost}prestashop>canadapost_9a5872e6530b14c9ec112f0821ce16bb'] = 'Calcola spese postali Canadesi';
$_MODULE['<{canadapost}prestashop>canadapost_a5daea18a1d4214028a538c3bf5a41cc'] = 'Offrire ai vostri clienti, modalità di consegna diversi post con il Canada';
$_MODULE['<{canadapost}prestashop>canadapost_883fa0069f4b0454e2277dd567ab3991'] = '\'Unità di Peso (LB o KG).\'';
$_MODULE['<{canadapost}prestashop>canadapost_5a3ceec65d417f5d92c26dbf0dccc00d'] = '\'Unità Dimensioni (CM o IN).\'';
$_MODULE['<{canadapost}prestashop>canadapost_4d470fde8487e755a50e9235e3dc13ab'] = 'deve essere configurato per utilizzare questo modulo correttamente';
$_MODULE['<{canadapost}prestashop>canadapost_2056ed4f6b76a94035f12c041350aa2f'] = 'Canada Post conto';
$_MODULE['<{canadapost}prestashop>canadapost_20449d3f0b6c6b9265a5cd2a470a6451'] = 'Packaging peso';
$_MODULE['<{canadapost}prestashop>canadapost_bfc00de34bc04366e7fee516adf7dca5'] = 'La tassa';
$_MODULE['<{canadapost}prestashop>canadapost_386aad80d82f8245e9ef80352a2240e8'] = 'Tutti gli articoli in un unico pacchetto';
$_MODULE['<{canadapost}prestashop>canadapost_8aaac24ade446a004c434b58e29afe85'] = 'Dividere un elemento per ogni pacchetto';
$_MODULE['<{canadapost}prestashop>canadapost_9c536dc938b99309eab40c9a06fc1c00'] = 'Canada Post Modulo di stato';
$_MODULE['<{canadapost}prestashop>canadapost_df432089df8810e4cb9011b96e6ac862'] = 'Il modulo spese postali Canadesi è configurato e online';
$_MODULE['<{canadapost}prestashop>canadapost_1e098f6c7ac70d1b66f48d1a060076a3'] = 'Il modulo spese postali Canadesi non è ancora configurato tu devi:';
$_MODULE['<{canadapost}prestashop>canadapost_3e203b9a16f360b88d90bba6eb61ce61'] = 'Riempire il \"Impostazioni generali\"  forma';
$_MODULE['<{canadapost}prestashop>canadapost_8c0987b9315003df7dae7f130e3cf58e'] = 'Selezionare il servizio di consegna';
$_MODULE['<{canadapost}prestashop>canadapost_e20f6d6f13fe70e78f6e2ab488493ccf'] = 'Webservice test di connessione';
$_MODULE['<{canadapost}prestashop>canadapost_52f4393e1b52ba63e27310ca92ba098c'] = 'Impostazioni generali';
$_MODULE['<{canadapost}prestashop>canadapost_277d63a9b24a09697e3c64092eaf4353'] = 'Categorie Impostazioni';
$_MODULE['<{canadapost}prestashop>canadapost_098eec2cabe2c39c6dec3fc522b6571a'] = 'Prodotti Impostazioni';
$_MODULE['<{canadapost}prestashop>canadapost_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aiuto';
$_MODULE['<{canadapost}prestashop>canadapost_d2126da975d5b9a5b846efaf57d3fd53'] = 'Configurazione generale';
$_MODULE['<{canadapost}prestashop>canadapost_4af6ad356ba7dd056b265944ef91cb5b'] = 'Apri il tuo conto in Canada';
$_MODULE['<{canadapost}prestashop>canadapost_db06a2900c66a3a2cb78fe3a470f1b85'] = 'Imballo Peso';
$_MODULE['<{canadapost}prestashop>canadapost_0274f749472f365e7d48a501e14793e6'] = 'Handling Fee';
$_MODULE['<{canadapost}prestashop>canadapost_83ad4fdaf06650e6d9d7ca18f82fb975'] = 'Localizzazione di configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_f489118ea95c746d648d36bb50c226f0'] = 'Unità di peso';
$_MODULE['<{canadapost}prestashop>canadapost_659c95668841b7d6602ead454b28d4ba'] = 'L\'unità di peso del tuo negozio (es. kg o lbs)';
$_MODULE['<{canadapost}prestashop>canadapost_cc13d156306185fd42a860da3049567c'] = 'Dimensioni unità';
$_MODULE['<{canadapost}prestashop>canadapost_f804c2bdebc117d9cde3cddad3b49845'] = 'L\'unità di dimensione del tuo negozio (cm ad esempio o in)';
$_MODULE['<{canadapost}prestashop>canadapost_2481447d04ae756836d32e3ade240ff4'] = 'Indirizzo di configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_5b179e75d464a04d8a04111131b3a3ca'] = 'La tua linea indirizzo 1';
$_MODULE['<{canadapost}prestashop>canadapost_281b2def1a9737b33f88013c94fdfeb8'] = 'La tua linea indirizzo 2';
$_MODULE['<{canadapost}prestashop>canadapost_d30f507473129e70c4b962ceccf175cf'] = '/ Codice postale';
$_MODULE['<{canadapost}prestashop>canadapost_d0585aac6bb77bb49423b2effca0e067'] = 'Il tuo Comune';
$_MODULE['<{canadapost}prestashop>canadapost_59716c97497eb9694541f7c3d37b1a4d'] = 'Paese';
$_MODULE['<{canadapost}prestashop>canadapost_f8f5a972333ee726fbe5bb52409c0ed0'] = 'Scegliere un paese ...';
$_MODULE['<{canadapost}prestashop>canadapost_4e9863cf5326e6714388045321665d07'] = 'Seleziona il paese all\'interno della lista.';
$_MODULE['<{canadapost}prestashop>canadapost_46a2a41cc6e552044816a2d04634545d'] = 'Stato';
$_MODULE['<{canadapost}prestashop>canadapost_cf1580798f7aba85d519afadf1ffd886'] = 'Seleziona uno stato ...';
$_MODULE['<{canadapost}prestashop>canadapost_02546d525ab356bd43c91e6b07447496'] = 'Non c\'è nessuna configurazione di stato per questo paese';
$_MODULE['<{canadapost}prestashop>canadapost_0ddc2a5660f7d095fff34d6b93077c80'] = 'Servizio di configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_8d6bd50f3fe3ee2f4513066c25e5fb4a'] = 'Calcul modalità';
$_MODULE['<{canadapost}prestashop>canadapost_96cf4eb97c979b15c96683bbe10fc84c'] = 'Utilizzando la modalità di calcul \"Tutti gli elementi in un unico pacchetto\"  utilizzerà automaticamente imballaggio dimensioni predefinite e servizi di consegna. Configurazioni specifiche per le categorie o prodotto non sarà utilizzato.';
$_MODULE['<{canadapost}prestashop>canadapost_5cdd307ba6e260beb4801c0c10e22a3a'] = 'Service Delivery';
$_MODULE['<{canadapost}prestashop>canadapost_78945de8de090e90045d299651a68a9b'] = 'Disponibile';
$_MODULE['<{canadapost}prestashop>canadapost_2d25c72c1b18e562f6654fff8e11711e'] = 'Non disponibile';
$_MODULE['<{canadapost}prestashop>canadapost_80982d4132c137d389a6b827e6bff451'] = 'Scegliere il servizio di consegna che sarà disponibile per i clienti.';
$_MODULE['<{canadapost}prestashop>canadapost_cf565402d32b79d33f626252949a6941'] = 'Salva la configurazione';
$_MODULE['<{canadapost}prestashop>canadapost_a438cfa1a870740754c9f4b35130cc04'] = 'Il tuo account Invia il Canada non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_805353d2862ea0e658c9ddda871540fa'] = 'Il tuo codice Zip / Postal non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_ef9bd955e165dfb0207877e9fe180aeb'] = 'La tua città non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_5ecc7697a320f93f3ee8fb4048dbd64c'] = 'Il vostro paese non è specificato';
$_MODULE['<{canadapost}prestashop>canadapost_e7bb7d2ee4d79c9b48cfc443781f00b5'] = 'Prestashop Impossibile connettersi al Canada Post webservices';
$_MODULE['<{canadapost}prestashop>canadapost_9d1b485edd50e6fbd288b340b386b07d'] = 'Nessuna descrizione dell\'errore trovato';
$_MODULE['<{canadapost}prestashop>canadapost_c888438d14855d7d96a2724ee9c306bd'] = 'Impostazioni aggiornate';
$_MODULE['<{canadapost}prestashop>canadapost_b9284bff13acffdd879ef4ac7fca5234'] = 'Impostazioni fallito';
$_MODULE['<{canadapost}prestashop>canadapost_67e19ffdaa0a11e69349810403a9727e'] = 'È necessario configurare \"Impostazioni generali\"  sulla scheda prima di utilizzare questa scheda.';
$_MODULE['<{canadapost}prestashop>canadapost_a37b48e8684078c0620a997b3baeee9f'] = 'In questa scheda è possibile impostare una configurazione specifica per ogni categoria.';
$_MODULE['<{canadapost}prestashop>canadapost_f421827ff72ef9a61fb27aa0de62f1e4'] = 'ID Config';
$_MODULE['<{canadapost}prestashop>canadapost_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Categoria';
$_MODULE['<{canadapost}prestashop>canadapost_20cde117cbc92b9ec1fb4e5bc4a7b9bd'] = 'Costi aggiuntivi';
$_MODULE['<{canadapost}prestashop>canadapost_992a0f0542384f1ee5ef51b7cf4ae6c4'] = 'Servizi';
$_MODULE['<{canadapost}prestashop>canadapost_06df33001c1d7187fdd81ea1f5b277aa'] = 'Azioni';
$_MODULE['<{canadapost}prestashop>canadapost_66001bafca8edd8343802bd20cddc10e'] = 'Non c\'è configurazione specifica Canada Post per le categorie a questo punto.';
$_MODULE['<{canadapost}prestashop>canadapost_605c5ae9959cfe9cc0b0d630b8d3144f'] = 'Sei sicuro di voler cancellare questa specifica configurazione Canada Post per questa categoria?';
$_MODULE['<{canadapost}prestashop>canadapost_3e0cb9fd22b124c0839302fef54762d7'] = 'Aggiornamento di una regola';
$_MODULE['<{canadapost}prestashop>canadapost_dd593f8a542ab628cbba98c709255e60'] = 'Aggiungere una regola';
$_MODULE['<{canadapost}prestashop>canadapost_7fcafa7c47e984693fcb8a92c0fd1beb'] = 'Seleziona una categoria ...';
$_MODULE['<{canadapost}prestashop>canadapost_d725c0166e978cc30853996c70440873'] = 'È necessario selezionare una categoria.';
$_MODULE['<{canadapost}prestashop>canadapost_882830cb67e4069370c1be3a1ba4e12a'] = 'Questa categoria ha già una specifica configurazione Canada Post.';
$_MODULE['<{canadapost}prestashop>canadapost_fd0119c2a5fc18aa64887b5b7ab41c19'] = 'È verificato un errore, riprova.';
$_MODULE['<{canadapost}prestashop>canadapost_20f40087c53c662adfb4e780500eaa15'] = 'In questa scheda è possibile impostare una configurazione specifica per ogni prodotto.';
$_MODULE['<{canadapost}prestashop>canadapost_deb10517653c255364175796ace3553f'] = 'Prodotto';
$_MODULE['<{canadapost}prestashop>canadapost_2119cb0eeb7e202767f9fa56566efc50'] = 'Non c\'è configurazione specifica Canada Post per i prodotti a questo punto.';
$_MODULE['<{canadapost}prestashop>canadapost_d53b004866635789a76380f66c87e3df'] = 'Sei sicuro di voler cancellare questa specifica configurazione Canada Post per questo prodotto?';
$_MODULE['<{canadapost}prestashop>canadapost_3c4d710b56f4318dae775cff80619f84'] = 'Selezionare un prodotto ...';
$_MODULE['<{canadapost}prestashop>canadapost_9c07640370e4681bf98638d0c458cd2e'] = 'È necessario selezionare un prodotto.';
$_MODULE['<{canadapost}prestashop>canadapost_c018b9a37818d15477285eb915590d19'] = 'Questo prodotto ha già una specifica configurazione Canada Post.';
$_MODULE['<{canadapost}prestashop>canadapost_73e383f703902e137c2e6d8e2e85cc22'] = 'Benvenuti nel PrestaShop Canada Invia modulo configuratore.';
$_MODULE['<{canadapost}prestashop>canadapost_92640c80a67da1782a18304336405dac'] = 'Questa sezione vi aiuterà a capire come configurare questo modulo in modo corretto.';
$_MODULE['<{canadapost}prestashop>canadapost_ec0e6948e8f34818d80f27c309f46661'] = 'Vedi sotto per la descrizione di ogni campo:';
$_MODULE['<{canadapost}prestashop>canadapost_a5f7df92d8088761b0727fb1ce0a013a'] = 'Il tuo account Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_742e9dca63ccb97a592727c4c2c9abc8'] = 'È necessario iscriversi al sito Canada messaggio a questo indirizzo';
$_MODULE['<{canadapost}prestashop>canadapost_35ba940948fa0ea163fd01281de10e2f'] = 'Questo campo deve essere lo Zip / CAP del punto di pacchetto di partenza.';
$_MODULE['<{canadapost}prestashop>canadapost_81822348ace1ceabad5e9f8992ce9ea4'] = 'Questo campo deve essere il paese del punto di pacchetto di partenza.';
$_MODULE['<{canadapost}prestashop>canadapost_b9bba478eb4348e49e672e944b072b68'] = 'Queste caselle corrispondono ai servizi di consegna si vuole essere a disposizione (quando non c\'è nessuna configurazione specifica per il prodotto o la categoria di prodotto).';
$_MODULE['<{canadapost}prestashop>canadapost_b7c1051bdf970e718e2a3664ad3e31ac'] = 'Questa sezione consente di definire una specifica configurazione Canada Post per categoria di prodotti (quali oneri aggiuntivi).';
$_MODULE['<{canadapost}prestashop>canadapost_2911404cfaf6a4c3a6756e157b0edb62'] = 'Questa sezione consente di definire una specifica configurazione Canada Post per ogni prodotto (quali oneri aggiuntivi).';
$_MODULE['<{canadapost}prestashop>canadapost_902b0d55fddef6f8d651fe1035b7d4bd'] = 'Errore';
$_MODULE['<{canadapost}prestashop>canadapost_43c9c583cfcb8523ad269708ddcde8b8'] = 'Canada Webservice messaggio sembra essere il basso, si prega di attendere alcuni minuti e riprovare.';
$_MODULE['<{canadapost}prestashop>canadapost_f1c83c0ed9e0f992f7f448f7321d9743'] = 'Canada Webservice Messaggio scaduta.';
$_MODULE['<{canadapost}prestashop>canadapost_b7f155fe0169108902b447f572639d0b'] = 'Impossibile connettersi al CanadaPost.com';
